@@ -33,6 +33,6 @@ from spiders.bing import BingSpider, BingNewsSpider
 
 
 __all__ = [
-    "BingSpider, BingNewsSpider",
+    "BingSpider", "BingNewsSpider"
 ]
 
