@@ -11,8 +11,12 @@ from queue import Queue
 import re
 from tqdm import tqdm
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
-from models.result import SearchItem
-from utils.proxies import sign, auth, proxy
+try:
+    from models.result import SearchItem
+    from utils.proxies import sign, auth, proxy
+except:
+    from encrawler.models.result import SearchItem
+    from encrawler.utils.proxies import sign, auth, proxy
 from typing import List, Optional, Dict
 
 
