@@ -6,8 +6,11 @@ try:
     from basic_search_engine_spider import EngineBaseSpdier
 except:
     from .basic_search_engine_spider import EngineBaseSpdier 
-from utils.proxies import sign, auth, proxy
-from models.result import SearchItem
+# from utils.proxies import sign, auth, proxy
+try:
+    from models.result import SearchItem
+except:
+    from encrawler.models.result import SearchItem
 from typing import List, Optional, Union
 from lxml.etree import HTML
 from urllib import response
@@ -478,6 +481,7 @@ if __name__ == "__main__":
     }
     kwargs = {}
     kwargs["cookie"] = cookies
-    res = spider.search("维护国家主权和领土完整的能力", 0, 2, **kwargs)
+
+    res = spider.search("维护国家主权和领土完整的能力", 0, 2, proxy=proxies,**kwargs)
     for item in res:
         pprint(item.__dict__['title'])
