@@ -4,6 +4,15 @@ import hashlib
 import requests
 
 
+username = "t17893278083368"
+password = "mzss0wdm"
+tunnel = "u194.kdltps.com:15818"
+proxies = {
+    "http": f"http://{username}:{password}@{tunnel}",
+    "https": f"http://{username}:{password}@{tunnel}"
+}
+
+
 orderno = ""    
 secret = ""
 ip = "dtan.xiongmaodaili.com"
